@@ -17,7 +17,7 @@ class BoundChain:
 
         handler = self.handlers.pop(0)
         if handler.is_trigger(event_params):
-            self.data = await handler.new_event(token, event, event_params)
+            self.data = await handler.new_event(token, event, event_params, self.data)
             result = True
         else:
             result = False
